@@ -1,6 +1,6 @@
 package PerlPowerTools;
 
-our $VERSION = '1.036_002';
+our $VERSION = '1.001';
 
 1;
 
@@ -17,10 +17,8 @@ BSD utilities.
 
 =head1 DESCRIPTION
 
-The Unix Reconstruction Project. By default, these install into the
-F<~/perlpowertools> directory. You'll probably need to add that directory
-to C<PATH> to use them. You can install them anywhere you like by
-setting C<INSTALL_BASE> when you run F<Makefile.PL>.
+
+Unix Reconstruction Project
 
 =head2 Utilities
 
@@ -42,13 +40,11 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item banner - print large banner on printer
 
-=item base64 - base64 encode or decode
-
 =item basename -- print the basename of a file
 
 =item bc - An arbitrary precision calculator language
 
-=item cal - display a calendar
+=item cal - member of the Perl Power Tools
 
 =item cat - concatenate and print files.
 
@@ -120,8 +116,6 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item head - print the first lines of a file
 
-=item hexdump - dump a file in hex format
-
 =item id - show user information
 
 =item install - install files and directories
@@ -140,6 +134,10 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item mail - implementation of Berkeley mail(1)
 
+=item pmake - a perl 'make' replacement
+
+=item man - format and display the on-line manual page
+
 =item maze - generate a maze problem
 
 =item mimedecode - extract MIME attachments in uudecode-like manner
@@ -150,9 +148,7 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item moo - play a game of MOO
 
-=item morse - read morse and translate it to text
-
-=item nl - line numbering filter
+=item demorse - read morse and translate it to text
 
 =item od - dump files in octal and other formats
 
@@ -180,7 +176,7 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item pwd - working directory name
 
-=item rain - Let it rain.
+=item rain -- Let it rain.
 
 =item random - display lines at random, or exit with a random value
 
@@ -192,8 +188,6 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item robots - fight off villainous robots
 
-=item rot13 - rotate text 13 ASCII characters
-
 =item shar - create a shell archive of files
 
 =item sleep - suspend execution for a number of seconds
@@ -238,11 +232,11 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =item units - conversion program
 
-=item unlink - one file rm
-
 =item unpar - extract files from a Perl archive
 
-=item unshar - extract files from a shell archive
+=item unshar - extract files from a shell archive 
+
+=item uudecode, uuencode - encode/decode a binary file
 
 =item uudecode, uuencode - encode/decode a binary file
 
@@ -269,17 +263,18 @@ setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 This source is in Github:
 
-	https://github.com/briandfoy/PerlPowerTools
+	https://github.com/briandfoy/ppt
 
 =head1 AUTHOR
 
 brian d foy, C<< <bdfoy@cpan.org> >> is the current maintainer, even
-though he wrote none of the utilities.
+though he write none of the utilities.
+
+
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2004-2023 by various authors. See each program for
-specific information.
+Copyright (c) 2004-2014 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
